import { isString } from "../../../shared";
class MemoryHistory {
  constructor() {
    this.scrollRestoration = "auto";
    this.history = [""];
    this.position = 0;
    this._state = {};
  }
  get state() {
    return this._state;
  }
  get length() {
    return this.history.length;
  }
  back() {
    this.go(-1);
  }
  forward() {
    this.position = Math.min(this.position + 1, this.history.length - 1);
  }
  go(delta) {
    this.position = Math.max(
      0,
      Math.min(this.position + delta, this.history.length - 1)
    );
  }
  pushState(data, _, url) {
    if (!url)
      return;
    this.setLocation(isString(url) ? url : url.pathname);
  }
  replaceState(state, _, url) {
    if (!url)
      return;
    this._state = state;
    this.history.splice(this.position--, 1);
    this.setLocation(isString(url) ? url : url.pathname);
  }
  setLocation(location) {
    this.position++;
    if (this.position === this.history.length) {
      this.history.push(location);
    } else {
      this.history.splice(this.position);
      this.history.push(location);
    }
  }
}
function createMemoryHistory() {
  return new MemoryHistory();
}
export {
  MemoryHistory,
  createMemoryHistory
};
