import { isNumber } from "./unit";
import { noslash, slash } from "./url";
const STRIP_PAGE_ORDER_RE = /\/\[(\d*)\]/g;
function stripPageOrderFromPath(filePath) {
  return filePath.replace(STRIP_PAGE_ORDER_RE, "/");
}
function calcPageOrderScore(filePath) {
  let score = 1;
  for (const matches of filePath.matchAll(STRIP_PAGE_ORDER_RE) ?? []) {
    score *= Number(matches[1]);
  }
  return score;
}
function sortOrderedPageFiles(files) {
  return files.map(slash).sort(
    (fileA, fileB) => calcPageOrderScore(fileA) - calcPageOrderScore(fileB)
  ).map(stripPageOrderFromPath);
}
function isLoadedPage(page) {
  return typeof page === "object" && "$$loaded" in page;
}
function isLoadedMarkdownPage(page) {
  return isLoadedPage(page) && page.ext === ".md";
}
const splitRE = /\//g;
const htmlExtRE = /(?:index)?\.html$/;
const DATA_ASSET_BASE_PATH = "/_immutable/data";
function resolveDataAssetID(pathname, layoutIndex) {
  const id = `${isNumber(layoutIndex) ? `$${layoutIndex}:` : ""}${pathname.replace(splitRE, "_").replace(htmlExtRE, "")}`;
  return id;
}
const layoutIndexRE = /^\/?\$\d+/;
function parseDataAssetURL(url) {
  const pathname = noslash(
    decodeURI(url.pathname).replace(DATA_ASSET_BASE_PATH, "")
  );
  const [layoutIndex, route] = layoutIndexRE.test(pathname) ? pathname.slice(1).split(":") : [-1, pathname];
  let routePath = route.replace(/_/g, "/").replace(/\.json$/, "");
  if (!routePath.endsWith("/"))
    routePath += ".html";
  return {
    url: new URL(routePath, url.href),
    layoutIndex: Number(layoutIndex)
  };
}
export {
  DATA_ASSET_BASE_PATH,
  isLoadedMarkdownPage,
  isLoadedPage,
  parseDataAssetURL,
  resolveDataAssetID,
  sortOrderedPageFiles,
  stripPageOrderFromPath
};
